<?php
/**
 * niceblog Theme Customizer
 *
 * @package niceblog
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function niceblog_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
	// Footer option
	$wp_customize->add_section("home_page_set", array(
		"title" => __("Footer Section", "niceblog"),
		"priority" => 35,
	));
	
		// Footer Copy Right Text
			$wp_customize->add_setting("niceblog_copyright_text", array(
				"default" => "",
				"placeholder"=>'home',
				"transport" => "refresh",
				'sanitize_callback' => 'sanitize_text_field'
			));
			$wp_customize->add_control(new WP_Customize_Control(
				$wp_customize,
				"niceblog_copyright_text",
				array(
					"label" => __("Footer Copy Right Text", "niceblog"),
					"section" => "home_page_set",
					"settings" => "niceblog_copyright_text",
					"type" => "text",
					
				)
			));

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'niceblog_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'niceblog_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'niceblog_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function niceblog_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function niceblog_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function niceblog_customize_preview_js() {
	wp_enqueue_script( 'niceblog-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '115', true );
}
add_action( 'customize_preview_init', 'niceblog_customize_preview_js' );
